nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Emr

Struct Emr 

#[repr(transparent)]
pub struct Emr(pub u32);
External Match Register. The EMR controls the match function and the external match pins.

Tuple Fields

0: u32

Implementations

Source

impl Emr

pub const fn em0(&self) -> bool

External Match 0. This bit reflects the state of output MAT0, whether or not this output is connected to a pin. When a match occurs between the TC and MR0, this bit can either toggle, go LOW, go HIGH, or do nothing, as selected by EMR[5:4]. This bit is driven to the MAT pins if the match function is selected via IOCON. 0 = LOW. 1 = HIGH.

pub const fn set_em0(&mut self, val: bool)

External Match 0. This bit reflects the state of output MAT0, whether or not this output is connected to a pin. When a match occurs between the TC and MR0, this bit can either toggle, go LOW, go HIGH, or do nothing, as selected by EMR[5:4]. This bit is driven to the MAT pins if the match function is selected via IOCON. 0 = LOW. 1 = HIGH.

pub const fn em1(&self) -> bool

External Match 1. This bit reflects the state of output MAT1, whether or not this output is connected to a pin. When a match occurs between the TC and MR1, this bit can either toggle, go LOW, go HIGH, or do nothing, as selected by EMR[7:6]. This bit is driven to the MAT pins if the match function is selected via IOCON. 0 = LOW. 1 = HIGH.

pub const fn set_em1(&mut self, val: bool)

External Match 1. This bit reflects the state of output MAT1, whether or not this output is connected to a pin. When a match occurs between the TC and MR1, this bit can either toggle, go LOW, go HIGH, or do nothing, as selected by EMR[7:6]. This bit is driven to the MAT pins if the match function is selected via IOCON. 0 = LOW. 1 = HIGH.

pub const fn em2(&self) -> bool

External Match 2. This bit reflects the state of output MAT2, whether or not this output is connected to a pin. When a match occurs between the TC and MR2, this bit can either toggle, go LOW, go HIGH, or do nothing, as selected by EMR[9:8]. This bit is driven to the MAT pins if the match function is selected via IOCON. 0 = LOW. 1 = HIGH.

pub const fn set_em2(&mut self, val: bool)

External Match 2. This bit reflects the state of output MAT2, whether or not this output is connected to a pin. When a match occurs between the TC and MR2, this bit can either toggle, go LOW, go HIGH, or do nothing, as selected by EMR[9:8]. This bit is driven to the MAT pins if the match function is selected via IOCON. 0 = LOW. 1 = HIGH.

pub const fn em3(&self) -> bool

External Match 3. This bit reflects the state of output MAT3, whether or not this output is connected to a pin. When a match occurs between the TC and MR3, this bit can either toggle, go LOW, go HIGH, or do nothing, as selected by MR[11:10]. This bit is driven to the MAT pins if the match function is selected via IOCON. 0 = LOW. 1 = HIGH.

pub const fn set_em3(&mut self, val: bool)

External Match 3. This bit reflects the state of output MAT3, whether or not this output is connected to a pin. When a match occurs between the TC and MR3, this bit can either toggle, go LOW, go HIGH, or do nothing, as selected by MR[11:10]. This bit is driven to the MAT pins if the match function is selected via IOCON. 0 = LOW. 1 = HIGH.

pub const fn emc0(&self) -> Emc0

External Match Control 0. Determines the functionality of External Match 0.

pub const fn set_emc0(&mut self, val: Emc0)

External Match Control 0. Determines the functionality of External Match 0.

pub const fn emc1(&self) -> Emc1

External Match Control 1. Determines the functionality of External Match 1.

pub const fn set_emc1(&mut self, val: Emc1)

External Match Control 1. Determines the functionality of External Match 1.

pub const fn emc2(&self) -> Emc2

External Match Control 2. Determines the functionality of External Match 2.

pub const fn set_emc2(&mut self, val: Emc2)

External Match Control 2. Determines the functionality of External Match 2.

pub const fn emc3(&self) -> Emc3

External Match Control 3. Determines the functionality of External Match 3.

pub const fn set_emc3(&mut self, val: Emc3)

External Match Control 3. Determines the functionality of External Match 3.